@@ -1,7 +1,9 @@
-try:
-    import httplib  # Python 2
-except ImportError:
-    import http.client as httplib  # Python 3
+try:  # Python 3
+    import http.client as httplib
+    from urllib.parse import parse_qs
+except ImportError:  # Python 2
+    import httplib
+    from urlparse import parse_qs
 
 from .exceptions import QuickbooksException, SevereException
 
@@ -24,6 +26,7 @@ class QuickBooks(object):
     callback_url = ''
     session = None
     sandbox = False
+    minorversion = None
 
     qbService = None
 
@@ -75,6 +78,9 @@ class QuickBooks(object):
         if 'sandbox' in kwargs:
             cls.sandbox = kwargs['sandbox']
 
+        if 'minorversion' in kwargs:
+            cls.minorversion = kwargs['minorversion']
+
         return QuickBooks.__instance
 
     @classmethod
@@ -116,12 +122,10 @@ class QuickBooks(object):
         response = self.qbService.get_raw_request_token(
            params={'oauth_callback': self.callback_url})
 
-        content = str.split(response.content, '&')
+        oauth_resp = parse_qs(response.text)
 
-        self.request_token = str.split(content[2], "=")[1]
-        self.request_token_secret = str.split(content[0], "=")[1]
-        #self.request_token, self.request_token_secret = self.qbService.get_raw_request_token(
-        #   params={'oauth_callback': self.callback_url})
+        self.request_token = oauth_resp['oauth_token']
+        self.request_token_secret = oauth_resp['oauth_token_secret']
 
         return self.qbService.get_authorize_url(self.request_token)
 
@@ -153,6 +157,12 @@ class QuickBooks(object):
         return session
 
     def make_request(self, request_type, url, request_body=None, content_type='application/json'):
+
+        params = {}
+
+        if self.minorversion:
+            params['minorversion'] = self.minorversion
+
         if not request_body:
             request_body = {}
 
@@ -164,7 +174,7 @@ class QuickBooks(object):
             'Accept': 'application/json'
         }
 
-        req = self.session.request(request_type, url, True, self.company_id, headers=headers, data=request_body)
+        req = self.session.request(request_type, url, True, self.company_id, headers=headers, params=params, data=request_body)
 
         try:
             result = req.json()
@@ -194,7 +204,7 @@ class QuickBooks(object):
 
             code = ""
             if "code" in error:
-                code = error["code"]
+                code = int(error["code"])
 
             if code >= 10000:
                 raise SevereException(message, code, detail)
